import { Emitter, Event } from '@vscode/monaco-editor/esm/vs/base/common/event';
import { Keybinding, ResolvedKeybinding } from '@vscode/monaco-editor/esm/vs/base/common/keyCodes';
import { Disposable } from '@vscode/monaco-editor/esm/vs/base/common/lifecycle';
import { IContextKeyServiceTarget } from '@vscode/monaco-editor/esm/vs/platform/contextkey/common/contextkey';
import { IKeyboardEvent } from '@vscode/monaco-editor/esm/vs/platform/keybinding/common/keybinding';
import { ResolvedKeybindingItem } from '@vscode/monaco-editor/esm/vs/platform/keybinding/common/resolvedKeybindingItem';
import { IStatusbarService } from '@vscode/monaco-editor/esm/vs/platform/statusbar/common/statusbar';
import { ITelemetryService } from '@vscode/monaco-editor/esm/vs/platform/telemetry/common/telemetry';
import { IJSONSchema } from '@vscode/monaco-editor/esm/vs/base/common/jsonSchema';
import { KeybindingResolver, IResolveResult } from './keybinding-resolver';
import { ICommandService, INotificationService, IContextKeyService, IKeybindingService, IKeybindingEvent } from '@workbench-stack/core';
export interface KeybindingsSchemaContribution {
    readonly onDidChange?: Event<void>;
    getSchemaAdditions(): IJSONSchema[];
}
export declare type WorkbenchActionExecutedEvent = {
    id: string;
    from: string;
};
export declare type WorkbenchActionExecutedClassification = {
    id: {
        classification: 'SystemMetaData';
        purpose: 'FeatureInsight';
    };
    from: {
        classification: 'SystemMetaData';
        purpose: 'FeatureInsight';
    };
};
export declare abstract class AbstractKeybindingService extends Disposable implements IKeybindingService {
    private _contextKeyService;
    protected _commandService: ICommandService;
    protected _telemetryService: ITelemetryService;
    private _notificationService;
    private _statusService;
    _serviceBrand: undefined;
    protected readonly _onDidUpdateKeybindings: Emitter<IKeybindingEvent>;
    get onDidUpdateKeybindings(): Event<IKeybindingEvent>;
    private _currentChord;
    private _currentChordChecker;
    private _currentChordStatusMessage;
    get inChordMode(): boolean;
    constructor(_contextKeyService: IContextKeyService, _commandService: ICommandService, _telemetryService: ITelemetryService, _notificationService: INotificationService, _statusService: IStatusbarService);
    dispose(): void;
    protected abstract _getResolver(): KeybindingResolver;
    protected abstract _documentHasFocus(): boolean;
    abstract resolveKeybinding(keybinding: Keybinding): ResolvedKeybinding[];
    abstract resolveKeyboardEvent(keyboardEvent: IKeyboardEvent): ResolvedKeybinding;
    abstract resolveUserBinding(userBinding: string): ResolvedKeybinding[];
    abstract registerSchemaContribution(contribution: KeybindingsSchemaContribution): void;
    abstract _dumpDebugInfo(): string;
    abstract _dumpDebugInfoJSON(): string;
    getDefaultKeybindingsContent(): string;
    getDefaultKeybindings(): ResolvedKeybindingItem[];
    getKeybindings(): ResolvedKeybindingItem[];
    customKeybindingsCount(): number;
    lookupKeybindings(commandId: string): ResolvedKeybinding[];
    lookupKeybinding(commandId: string): ResolvedKeybinding | undefined;
    dispatchEvent(e: IKeyboardEvent, target: IContextKeyServiceTarget): boolean;
    softDispatch(e: IKeyboardEvent, target: IContextKeyServiceTarget): IResolveResult | null;
    private _enterChordMode;
    private _leaveChordMode;
    dispatchByUserSettingsLabel(userSettingsLabel: string, target: IContextKeyServiceTarget): void;
    protected _dispatch(e: IKeyboardEvent, target: IContextKeyServiceTarget): boolean;
    private _doDispatch;
    mightProducePrintableCharacter(event: IKeyboardEvent): boolean;
}
